pub struct VcEmulationBindings { /* private fields */ }๐Deprecated since 0.9.0:
migration-only: decode pre-row bindings records and convert their entries with VcEmulationBinding::from_legacy_record. Will be removed in 0.10.0.
Available on crate feature
extensions-draft and crate feature virtual-clients-draft and (32-bit or 64-bit) only.Expand description
Per-group bindings record of the storage layout that preceded per-epoch
VcEmulationBinding rows. Only for decoding stored records and
converting their entries with VcEmulationBinding::from_legacy_record.
Implementations
Sourceimpl VcEmulationBindings
impl VcEmulationBindings
Sourcepub fn into_entries(self) -> Vec<(GroupEpoch, EpochId)>
pub fn into_entries(self) -> Vec<(GroupEpoch, EpochId)>
The (group_epoch, epoch_id) pairs of the record, oldest first.