pub struct SafeAad { /* private fields */ }Available on (32-bit or 64-bit) and crate feature
extensions-draft-08 only.Expand description
A Safe AAD struct as it appears at the beginning of an MLS message’s
authenticated_data field when negotiated for the group.
Implementations
Sourceimpl SafeAad
impl SafeAad
Sourcepub fn from_items(items: Vec<SafeAadItem>) -> Result<Self, SafeAadError>
pub fn from_items(items: Vec<SafeAadItem>) -> Result<Self, SafeAadError>
Build a SafeAad from a list of items.
Returns an error if items are not sorted in strictly-increasing
ComponentId order or if any ComponentId appears more than once.
Sourcepub fn items(&self) -> &[SafeAadItem]
pub fn items(&self) -> &[SafeAadItem]
Returns all items.
Sourcepub fn get(&self, component_id: ComponentId) -> Option<&[u8]>
pub fn get(&self, component_id: ComponentId) -> Option<&[u8]>
Look up the data carried for a given ComponentId.
Returns None if there is no item tagged with that id.