pub enum LeafNodeLifetimePolicy {
Verify,
Skip,
}Available on 32-bit or 64-bit only.
Verify or skip the validation of leaf node lifetimes in the ratchet tree when joining a group.
Variants
Verify
Verify the lifetime of leaf nodes in the ratchet tree.
NOTE: Only leaf nodes that have never been updated have a lifetime.
Skip
Skip the verification of the lifeimte in leaf nodes in the ratchet tree.