pub enum NewGroupError<StorageError> {
LibraryError(LibraryError),
NoMatchingKeyPackage,
StorageError(StorageError),
UnsupportedProposalType,
UnsupportedExtensionType,
InvalidExtensions(InvalidExtensionError),
GroupAlreadyExists,
UnsupportedCiphersuite(Ciphersuite),
VirtualClientsError(VirtualClientsError),
RegisterVcDerivationEpoch(RegisterVcDerivationEpochError<StorageError>),
}Available on 32-bit or 64-bit only.
New group error
Variants
LibraryError(LibraryError)
See LibraryError for more details.
NoMatchingKeyPackage
No matching KeyPackage was found in the key store.
StorageError(StorageError)
Error accessing the storage.
UnsupportedProposalType
Unsupported proposal type in required capabilities.
UnsupportedExtensionType
Unsupported extension type in required capabilities.
InvalidExtensions(InvalidExtensionError)
Invalid extensions set in configuration
GroupAlreadyExists
A group with the given GroupId already exists.
UnsupportedCiphersuite(Ciphersuite)
The ciphersuite is not supported by the crypto provider.
VirtualClientsError(VirtualClientsError)
Available on crate feature
virtual-clients-draft only.A virtual-clients processing error occurred.
RegisterVcDerivationEpoch(RegisterVcDerivationEpochError<StorageError>)
Available on crate feature
virtual-clients-draft only.The group is an emulation group, and registering the derivation epoch of its initial epoch failed.