pub enum PastEpochDeletionPolicy {
MaxEpochs(usize),
KeepAll,
}Expand description
Configures the automatic deletion of past epoch secrets.
WARNING
Policies other than MaxEpochs(0) enable the storage of message secrets from past epochs.
It is a trade-off between functionality and forward secrecy and should only be enabled
if the Delivery Service cannot guarantee that application messages will be sent in
the same epoch in which they were generated. The number for max_epochs should be
as low as possible.
If the MaxEpochs policy is set to MaxEpochs(usize::MAX), if will be returned as KeepAll after deserialization due to backwards compatibility constraints.
Variants
MaxEpochs(usize)
Keep at most n past epoch secrets.
KeepAll
Keep all past epoch secrets.
NOTE: The application is responsible for deleting past epoch secrets when
KeepAll is set. Past epoch secrets can be deleted manually using: