pub enum Propose {
Add(KeyPackage),
Update(LeafNodeParameters),
Remove(u32),
RemoveCredential(Credential),
PreSharedKey(PreSharedKeyId),
GroupContextExtensions(Extensions<GroupContext>),
UpdateAppDataComponent {
component_id: ComponentId,
update: Vec<u8>,
},
RemoveAppDataComponent {
component_id: ComponentId,
},
Custom(CustomProposal),
}Available on 32-bit or 64-bit only.
Helper for building a proposal based on the raw values.
Variants
Add(KeyPackage)
An add proposal requires a key package of the addee.
Update(LeafNodeParameters)
An update proposal requires a new leaf node.
An update proposal is always queued by reference as per RFC 9420 a member must not commit its own update proposal.
Remove(u32)
A remove proposal consists of the leaf index of the leaf to be removed.
RemoveCredential(Credential)
A remove proposal for the leaf with the credential.
A PSK proposal gets a pre shared key id.
GroupContextExtensions(Extensions<GroupContext>)
Propose adding new group context extensions.
UpdateAppDataComponent
Available on crate feature
extensions-draft only.Propose an update to a component in the
AppDataDictionary
Fields

component_id: ComponentIdThe component_id to update in the dictionary
RemoveAppDataComponent
Available on crate feature
extensions-draft only.Propose removal of a component in the
AppDataDictionary
Fields

component_id: ComponentIdThe component_id to remove in the dictionary
Custom(CustomProposal)
A custom proposal with semantics to be implemented by the application.