pub enum RegisterVcDerivationEpochError<StorageError> {
ApplicationExportTree(ApplicationExportTreeError),
MissingApplicationExportTree,
VirtualClients(VirtualClientsError),
Storage(StorageError),
}Available on crate feature
virtual-clients-draft and (32-bit or 64-bit) only.Expand description
Errors returned when deriving and persisting the state of a virtual-clients derivation epoch. OpenMLS does this implicitly for emulation groups, so this error is always wrapped in the error of the operation that triggered the registration.
Variants
ApplicationExportTree(ApplicationExportTreeError)
Puncturing the application exporter for the virtual-clients
component failed. See
ApplicationExportTreeError for
more details.
MissingApplicationExportTree
The emulation group has no application export tree to source the derivation epoch from. This happens when a group stored by an OpenMLS version without application-exporter support is marked as an emulation group.
VirtualClients(VirtualClientsError)
See VirtualClientsError
for more details.
Storage(StorageError)
Persisting the derived virtual-clients state to storage failed.