pub enum ResolveAppDataCommitError {
NotAnUnresolvedAppDataCommit,
StageCommit(StageCommitError),
}Available on crate feature
extensions-draft and (32-bit or 64-bit) only.Expand description
Error resolving a processed message carrying an unresolved app data commit.
Variants
NotAnUnresolvedAppDataCommit
The processed message does not carry an unresolved app data commit.
StageCommit(StageCommitError)
See StageCommitError for more details.