pub enum WelcomeError<StorageError> {
Show 32 variants
GroupSecrets(GroupSecretsError),
PrivateInitKeyNotFound,
LibraryError(LibraryError),
CiphersuiteMismatch,
GroupInfo(GroupInfoError),
JoinerSecretNotFound,
MissingRatchetTree,
ConfirmationTagMismatch,
InvalidGroupInfoSignature,
UnsupportedMlsVersion,
UnsupportedCapability,
UnsupportedCiphersuite(Ciphersuite),
UnknownSender,
NotAWelcomeMessage,
MalformedWelcomeMessage,
UnableToDecrypt,
UnsupportedExtensions,
Psk(PskError),
NoMatchingEncryptionKey,
NoMatchingKeyPackage,
PublicTreeError(PublicTreeError),
PublicGroupError(CreationFromExternalError<StorageError>),
LeafNodeValidation(LeafNodeValidationError),
StorageError(StorageError),
GroupAlreadyExists,
VirtualClientsError(VirtualClientsError),
RegisterVcDerivationEpoch(RegisterVcDerivationEpochError<StorageError>),
KeySchedule(KeyScheduleError),
SubgroupParameterMismatch,
SubgroupEpochInvalid,
SubgroupLeafMismatch,
SubgroupParentMismatch,
}Expand description
Welcome error
Variants
GroupSecrets(GroupSecretsError)
See GroupSecretsError for more details.
PrivateInitKeyNotFound
Private part of init_key not found in key store.
LibraryError(LibraryError)
See LibraryError for more details.
CiphersuiteMismatch
Ciphersuites in Welcome and key package bundle don’t match.
GroupInfo(GroupInfoError)
See GroupInfoError for more details.
JoinerSecretNotFound
No joiner secret found in the Welcome message.
MissingRatchetTree
No ratchet tree available to build initial tree after receiving a Welcome message.
ConfirmationTagMismatch
The computed confirmation tag does not match the expected one.
InvalidGroupInfoSignature
The signature on the GroupInfo is not valid.
UnsupportedMlsVersion
We don’t support the version of the group we are trying to join.
UnsupportedCapability
We don’t support all capabilities of the group.
UnsupportedCiphersuite(Ciphersuite)
The crypto provider doesn’t support the ciphersuite of the group we are trying to join.
UnknownSender
Sender not found in tree.
NotAWelcomeMessage
The provided message is not a Welcome message.
MalformedWelcomeMessage
Malformed Welcome message.
UnableToDecrypt
Could not decrypt the Welcome message.
UnsupportedExtensions
Unsupported extensions found in the GroupContext or KeyPackage of another member.
Psk(PskError)
See PskError for more details.
NoMatchingEncryptionKey
No matching encryption key was found in the key store.
NoMatchingKeyPackage
No matching key package was found in the key store.
PublicTreeError(PublicTreeError)
This error indicates the public tree is invalid. See PublicTreeError for more details.
PublicGroupError(CreationFromExternalError<StorageError>)
This error indicates the public tree is invalid. See
CreationFromExternalError for more details.
LeafNodeValidation(LeafNodeValidationError)
This error indicates the leaf node is invalid. See LeafNodeValidationError for more details.
StorageError(StorageError)
This error indicates that an error occurred while reading or writing from/to storage.
GroupAlreadyExists
A group with this GroupId already exists.
VirtualClientsError(VirtualClientsError)
virtual-clients-draft only.A virtual-clients error occurred while deriving or validating the virtual client’s join material.
RegisterVcDerivationEpoch(RegisterVcDerivationEpochError<StorageError>)
virtual-clients-draft only.The joined group is an emulation group, and registering the derivation epoch of the Welcome’s output epoch failed.
KeySchedule(KeyScheduleError)
This error indicates that computing the key schedule failed
SubgroupParameterMismatch
The subgroup’s protocol version or ciphersuite does not match the parent group (RFC 9420 11.3).
SubgroupEpochInvalid
The subgroup is not at epoch 1, as required for a branched subgroup (RFC 9420 11.3).
SubgroupLeafMismatch
A member of the subgroup does not match any member of the parent group (RFC 9420 11.3).
SubgroupParentMismatch
The parent group or epoch referenced by the subgroup’s branch PSK does not match the provided parent group information (RFC 9420 11.3).