pub struct GroupContext { /* private fields */ }Expand description
8.1 Group Context
struct {
ProtocolVersion version = mls10;
CipherSuite cipher_suite;
opaque group_id<V>;
uint64 epoch;
opaque tree_hash<V>;
opaque confirmed_transcript_hash<V>;
Extension extensions<V>;
} GroupContext;
The [`GroupContext`] is a state object maintained which summarizes the group
state agreed upon by each member of the group.Implementations
Sourceimpl GroupContext
impl GroupContext
Sourcepub fn safe_aad_required(&self) -> bool
Available on crate feature extensions-draft-08 only.
pub fn safe_aad_required(&self) -> bool
extensions-draft-08 only.Whether Safe AAD framing is active for messages in this group.
Returns true exactly when the app_data_dictionary GroupContext
extension contains a safe_aad component (the value bytes are not
inspected here, an empty ComponentsList is still “present”).
Per the Safe AAD spec section 4.9, when this is true the
authenticated_data field always starts with the SafeAAD struct.
Sourcepub fn safe_aad_required_components(
&self,
) -> Result<Option<Vec<ComponentId>>, SafeAadError>
Available on crate feature extensions-draft-08 only.
pub fn safe_aad_required_components( &self, ) -> Result<Option<Vec<ComponentId>>, SafeAadError>
extensions-draft-08 only.The list of ComponentIds required to be understood by every member
for Safe AAD purposes.
Returns Ok(None) when the safe_aad component is absent from the
app_data_dictionary GroupContext extension, Ok(Some(list)) when it
is present and parses cleanly (the list may be empty), and an error
when the component value fails to decode as a ComponentsList.
Sourcepub fn protocol_version(&self) -> ProtocolVersion
pub fn protocol_version(&self) -> ProtocolVersion
Return the protocol version.
Sourcepub fn ciphersuite(&self) -> Ciphersuite
pub fn ciphersuite(&self) -> Ciphersuite
Return the ciphersuite.
Sourcepub fn epoch(&self) -> GroupEpoch
pub fn epoch(&self) -> GroupEpoch
Return the epoch.
Sourcepub fn confirmed_transcript_hash(&self) -> &[u8] ⓘ
pub fn confirmed_transcript_hash(&self) -> &[u8] ⓘ
Return the confirmed transcript hash.
Sourcepub fn extensions(&self) -> &Extensions<GroupContext>
pub fn extensions(&self) -> &Extensions<GroupContext>
Return the extensions.
Sourcepub fn required_capabilities(&self) -> Option<&RequiredCapabilitiesExtension>
pub fn required_capabilities(&self) -> Option<&RequiredCapabilitiesExtension>
Get the required capabilities extension.