pub struct HandshakeConfirmationData {
pub epoch: GroupEpoch,
pub generation: u32,
pub generation_id: Option<GenerationId>,
}Available on crate feature
virtual-clients-draft and (32-bit or 64-bit) only.Expand description
Bookkeeping a virtual client needs to confirm a handshake message (proposal or commit) that was framed as a PrivateMessage.
Pass epoch and generation to MlsGroup::confirm_handshake_message
once the DS has accepted the message, to delete the retained handshake
secret. generation_id is present when the group is bound to an emulation
epoch and is attached to the fanned-out message so a strongly-consistent DS
can detect generation collisions between siblings; it is None otherwise.
Fields
epoch: GroupEpochThe epoch the message was encrypted in, which is the epoch before a commit is merged.
generation: u32The handshake-ratchet generation used for encryption.
generation_id: Option<GenerationId>The GenerationId to attach to the fanned-out message, present when
the group is bound to an emulation epoch and None otherwise.