MlsGroupJoinConfigBuilder

Struct MlsGroupJoinConfigBuilder 

pub struct MlsGroupJoinConfigBuilder { /* private fields */ }
Available on 32-bit or 64-bit only.
Builder struct for an MlsGroupJoinConfig.

Implementations

Source

impl MlsGroupJoinConfigBuilder

pub fn wire_format_policy(self, wire_format_policy: WireFormatPolicy) -> Self

Sets the wire_format property of the MlsGroupJoinConfig.

pub fn padding_size(self, padding_size: usize) -> Self

Sets the padding_size property of the MlsGroupJoinConfig.

pub fn max_past_epochs(self, max_past_epochs: usize) -> Self

Sets the max_past_epochs property of the MlsGroupJoinConfig.

This method overrides the policy set by Self::set_past_epoch_deletion_policy(), and is equivalent to setting the past epoch deletion policy to PastEpochDeletionPolicy::MaxEpochs(max_past_epochs).

WARNING

This feature enables the storage of message secrets from past epochs. It is a trade-off between functionality and forward secrecy and should only be enabled if the Delivery Service cannot guarantee that application messages will be sent in the same epoch in which they were generated. The number for max_epochs should be as low as possible.

pub fn set_past_epoch_deletion_policy( self, policy: PastEpochDeletionPolicy, ) -> Self

Set the policy for deleting past epoch secrets.

By default, storage of past epoch secrets is disabled.

This method overrides the configuration set by Self::max_past_epochs().

WARNING

This feature enables the storage of message secrets from past epochs. It is a trade-off between functionality and forward secrecy and should only be enabled if the Delivery Service cannot guarantee that application messages will be sent in the same epoch in which they were generated. The number for max_epochs should be as low as possible.

pub fn number_of_resumption_psks(self, number_of_resumption_psks: usize) -> Self

Sets the number_of_resumption_psks property of the MlsGroupJoinConfig.

pub fn use_ratchet_tree_extension( self, use_ratchet_tree_extension: bool, ) -> Self

Sets the use_ratchet_tree_extension property of the MlsGroupJoinConfig.

pub fn sender_ratchet_configuration( self, sender_ratchet_configuration: SenderRatchetConfiguration, ) -> Self

Sets the sender_ratchet_configuration property of the MlsGroupJoinConfig.

pub fn build(self) -> MlsGroupJoinConfig

Finalizes the builder and returns an MlsGroupJoinConfig.