PastEpochDeletion

Struct PastEpochDeletion 

pub struct PastEpochDeletion { /* private fields */ }
Available on 32-bit or 64-bit only.
The input to MlsGroup::delete_past_epoch_secrets().

This struct can be used for manual deletion of past epoch secrets by the application.

An MlsGroup also applies automatic deletion of past epoch secrets by default.

For more information, see PastEpochDeletionPolicy and MlsGroup::set_past_epoch_deletion_policy().

These methods can be used by the application to set up time-based deletion schedules:

NOTE: Epoch secrets that were created using openmls=0.8.1 or earlier will not yet include a timestamp. After migration, these may not always be deleted by applying a time-based PastEpochDeletion. Only if a new secret that does include a timestamp is added later, and it matches the time-based condition in the PastEpochDeletion, all earlier past epoch secrets without timestamps will be deleted, as well. However, otherwise, past epoch secrets without timestamps will not be affected by applying time-based PastEpochDeletions.

To manually delete all past epoch secrets without timestamps, see: PastEpochDeletion::delete_all_without_timestamps()

Implementations

Source

impl PastEpochDeletion

pub fn older_than_duration(duration: Duration) -> Self

Delete all past epoch secrets older than a provided duration.

pub fn before_timestamp(timestamp: SystemTime) -> Self

Delete all past epoch secrets before a provided timestamp.

pub fn delete_all_without_timestamps() -> Self

Delete all past epoch secrets without timestamps.

NOTE: This will delete all past epoch secrets having the legacy format that does not include a timestamp.

pub fn delete_all() -> Self

Delete all past epoch secrets.

pub fn max_past_epochs(self, max_past_epochs: usize) -> Self

Set the number of max_past_epochs that should be kept, at most.