pub struct ProcessedWelcome { /* private fields */ }Expand description
A Welcome message that has been processed but not staged yet.
This may be used in order to retrieve information from the Welcome about
the ratchet tree and PSKs.
Use into_staged_welcome to stage it into a StagedWelcome.
Implementations
Sourceimpl ProcessedWelcome
impl ProcessedWelcome
Sourcepub fn new_from_welcome<Provider: OpenMlsProvider>(
provider: &Provider,
mls_group_config: &MlsGroupJoinConfig,
welcome: Welcome,
) -> Result<Self, WelcomeError<Provider::StorageError>>
pub fn new_from_welcome<Provider: OpenMlsProvider>( provider: &Provider, mls_group_config: &MlsGroupJoinConfig, welcome: Welcome, ) -> Result<Self, WelcomeError<Provider::StorageError>>
Creates a new processed Welcome message , which can be
inspected before creating a StagedWelcome.
This does not require a ratchet tree yet.
Sourcepub fn unverified_group_info(&self) -> &VerifiableGroupInfo
pub fn unverified_group_info(&self) -> &VerifiableGroupInfo
Get a reference to the GroupInfo in this Welcome message.
NOTE: The group info contains unverified values. Use with caution.
Sourcepub fn psks(&self) -> &[PreSharedKeyId]
pub fn psks(&self) -> &[PreSharedKeyId]
Get a reference to the PSKs in this Welcome message.
NOTE: The group info contains unverified values. Use with caution.
Sourcepub fn into_staged_welcome<Provider: OpenMlsProvider>(
self,
provider: &Provider,
ratchet_tree: Option<RatchetTreeIn>,
) -> Result<StagedWelcome, WelcomeError<Provider::StorageError>>
pub fn into_staged_welcome<Provider: OpenMlsProvider>( self, provider: &Provider, ratchet_tree: Option<RatchetTreeIn>, ) -> Result<StagedWelcome, WelcomeError<Provider::StorageError>>
Consume the ProcessedWelcome and combine it with the ratchet tree into
a StagedWelcome.
Sourcepub fn export_secret<CryptoProvider: OpenMlsCrypto>(
&self,
crypto: &CryptoProvider,
label: &str,
context: &[u8],
key_length: usize,
) -> Result<Vec<u8>, ExportSecretError>
pub fn export_secret<CryptoProvider: OpenMlsCrypto>( &self, crypto: &CryptoProvider, label: &str, context: &[u8], key_length: usize, ) -> Result<Vec<u8>, ExportSecretError>
Exports a secret from the epoch of the group that is joined
using this ProcessedWelcome.
Returns ExportSecretError::KeyLengthTooLong if the requested
key length is too long.
Sourcepub fn own_key_package(&self) -> Option<&KeyPackage>
pub fn own_key_package(&self) -> Option<&KeyPackage>
Retrieve a reference to the own KeyPackage that was retrieved from local storage as
part of Welcome processing, and is used to build the group