ProposalQueue

Struct ProposalQueue 

pub struct ProposalQueue { /* private fields */ }
Available on 32-bit or 64-bit only.
Proposal queue that helps filtering and sorting Proposals received during one epoch. The Proposals are stored in a HashMap which maps Proposal references to Proposals, such that, given a reference, a proposal can be accessed efficiently. To enable iteration over the queue in order, the ProposalQueue also contains a vector of ProposalRefs.

Implementations

Source

impl ProposalQueue

pub fn get(&self, proposal_reference: &ProposalRef) -> Option<&QueuedProposal>

Returns proposal for a given proposal ID

Source

impl ProposalQueue

pub fn app_ephemeral_proposals_for_component_id( &self, component_id: ComponentId, ) -> impl Iterator<Item = QueuedAppEphemeralProposal<'_>>

Available on crate feature extensions-draft only.

Return an iterator over the QueuedAppEphemeralProposals in the proposal queue, in the order they appear in the commit.

pub fn unique_component_ids_for_app_ephemeral(&self) -> Vec<ComponentId>

Available on crate feature extensions-draft only.

Return the list of all ComponentIds available across all QueuedAppEphemeralProposals in the proposal queue, ordered by ComponentId.