pub struct VcDerivationEpochDeletion { /* private fields */ }Available on crate feature
virtual-clients-draft and (32-bit or 64-bit) only.Expand description
Selects the derivation epochs MlsGroup::delete_vc_derivation_epochs()
deletes: those superseded before a point in time, optionally capped to a
number of surviving epochs. An epoch is superseded when the next one is
registered. The newest epoch is never selected.
Implementations
Sourceimpl VcDerivationEpochDeletion
impl VcDerivationEpochDeletion
Sourcepub fn older_than_duration(duration: Duration) -> Self
pub fn older_than_duration(duration: Duration) -> Self
Delete all derivation epochs superseded more than duration ago.
Sourcepub fn before_timestamp(timestamp: SystemTime) -> Self
pub fn before_timestamp(timestamp: SystemTime) -> Self
Delete all derivation epochs superseded before timestamp.
Sourcepub fn max_epochs(self, max_epochs: usize) -> Self
pub fn max_epochs(self, max_epochs: usize) -> Self
Additionally cap the number of derivation epochs that survive.