pub struct WelcomeKeyMaterial { /* private fields */ }Available on 32-bit or 64-bit only.
The key material a client uses to process a Welcome message.
Implementations
Sourceimpl WelcomeKeyMaterial
impl WelcomeKeyMaterial
Sourcepub fn key_package_ref(
&self,
crypto: &impl OpenMlsCrypto,
) -> Result<KeyPackageRef, LibraryError>
pub fn key_package_ref( &self, crypto: &impl OpenMlsCrypto, ) -> Result<KeyPackageRef, LibraryError>
The KeyPackageRef addressed by the welcome’s encrypted group
secrets. The bundle computes it from its KeyPackage, the virtual-client
material carries the ref it was matched on.
Sourcepub fn init_private_key(&self) -> &HpkePrivateKey
pub fn init_private_key(&self) -> &HpkePrivateKey
The init private key used to decrypt the encrypted group secrets.
Sourcepub fn hpke_init_key(&self) -> &InitKey
pub fn hpke_init_key(&self) -> &InitKey
The public init key the encrypted group secrets are encrypted to.
Sourcepub fn key_package_bundle(&self) -> Option<&KeyPackageBundle>
pub fn key_package_bundle(&self) -> Option<&KeyPackageBundle>
The local KeyPackageBundle on the regular path, or None on the
virtual-client path. Checks that only apply when there is a local
KeyPackage to compare against branch on this.