pub enum CreationFromExternalError<StorageError> {
Show 13 variants
LibraryError(LibraryError),
TreeSyncError(TreeSyncFromNodesError),
UnknownSender,
InvalidGroupInfoSignature,
TreeHashMismatch,
UnsupportedMlsVersion,
UnsupportedCiphersuite(Ciphersuite),
LeafNodeValidation(LeafNodeValidationError),
WriteToStorageError(StorageError),
UnmergedLeafNotADescendant,
IntermediateNodeMissingUnmergedLeaf,
DuplicateEncryptionKey,
DuplicateSignatureKey,
}Expand description
Public group creation from external error.
Variants
LibraryError(LibraryError)
See LibraryError for more details.
TreeSyncError(TreeSyncFromNodesError)
This error indicates the public tree is invalid. See TreeSyncFromNodesError for more details.
UnknownSender
Sender not found in tree.
InvalidGroupInfoSignature
The signature on the GroupInfo is not valid.
TreeHashMismatch
The computed tree hash does not match the one in the GroupInfo.
UnsupportedMlsVersion
We don’t support the version of the group we are trying to join.
UnsupportedCiphersuite(Ciphersuite)
The ciphersuite is not supported by the crypto provider.
LeafNodeValidation(LeafNodeValidationError)
WriteToStorageError(StorageError)
Error writing to storage.
UnmergedLeafNotADescendant
A parent node has an unmerged leaf that is not a descendant of the node.
IntermediateNodeMissingUnmergedLeaf
Found a path from a parent with an unmerged leaf to the leaf with nodes that do not have that as a leaf
DuplicateEncryptionKey
The ratchet tree contains duplcate encryption keys
DuplicateSignatureKey
The ratchet tree contains duplcate signature keys