pub struct Capabilities { /* private fields */ }Expand description
Capabilities of LeafNodes.
struct {
ProtocolVersion versions<V>;
CipherSuite ciphersuites<V>;
ExtensionType extensions<V>;
ProposalType proposals<V>;
CredentialType credentials<V>;
} Capabilities;Implementations
Sourceimpl Capabilities
impl Capabilities
Sourcepub fn new(
versions: Option<&[ProtocolVersion]>,
ciphersuites: Option<&[Ciphersuite]>,
extensions: Option<&[ExtensionType]>,
proposals: Option<&[ProposalType]>,
credentials: Option<&[CredentialType]>,
) -> Self
pub fn new( versions: Option<&[ProtocolVersion]>, ciphersuites: Option<&[Ciphersuite]>, extensions: Option<&[ExtensionType]>, proposals: Option<&[ProposalType]>, credentials: Option<&[CredentialType]>, ) -> Self
Create a new Capabilities struct with the given configuration.
Any argument that is None is filled with the default values from the
global configuration.
Sourcepub fn empty() -> Self
pub fn empty() -> Self
Create new empty Capabilities.
Sourcepub fn builder() -> CapabilitiesBuilder
pub fn builder() -> CapabilitiesBuilder
Creates a new CapabilitiesBuilder for constructing Capabilities
Sourcepub fn versions(&self) -> &[ProtocolVersion]
pub fn versions(&self) -> &[ProtocolVersion]
Get a reference to the list of versions in this extension.
Sourcepub fn ciphersuites(&self) -> &[VerifiableCiphersuite]
pub fn ciphersuites(&self) -> &[VerifiableCiphersuite]
Get a reference to the list of ciphersuites in this extension.
Sourcepub fn extensions(&self) -> &[ExtensionType]
pub fn extensions(&self) -> &[ExtensionType]
Get a reference to the list of supported extensions.
Sourcepub fn proposals(&self) -> &[ProposalType]
pub fn proposals(&self) -> &[ProposalType]
Get a reference to the list of supported proposals.
Sourcepub fn credentials(&self) -> &[CredentialType]
pub fn credentials(&self) -> &[CredentialType]
Get a reference to the list of supported credential types.
Sourcepub fn with_grease(self, rand: &impl OpenMlsRand) -> Self
pub fn with_grease(self, rand: &impl OpenMlsRand) -> Self
Add random GREASE values to the capabilities to ensure extensibility.
This adds one random GREASE value to each capability list if no GREASE value is already present:
- Ciphersuites
- Extensions
- Proposals
- Credentials
GREASE values are used per RFC 9420 Section 13.5 to help prevent extensibility failures by ensuring implementations properly handle unknown values.
Example
use openmls::prelude::*;
use openmls_rust_crypto::OpenMlsRustCrypto;
let provider = OpenMlsRustCrypto::default();
// Create capabilities with GREASE values injected
let capabilities = Capabilities::builder()
.build()
.with_grease(provider.rand());
// Verify GREASE values were added
assert!(capabilities.ciphersuites().iter().any(|cs| cs.is_grease()));
assert!(capabilities.extensions().iter().any(|ext| ext.is_grease()));
assert!(capabilities.proposals().iter().any(|prop| prop.is_grease()));
assert!(capabilities.credentials().iter().any(|cred| cred.is_grease()));Trait Implementations
Sourceimpl Clone for Capabilities
impl Clone for Capabilities
Sourcefn clone(&self) -> Capabilities
fn clone(&self) -> Capabilities
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for Capabilities
impl Debug for Capabilities
Sourceimpl Default for Capabilities
impl Default for Capabilities
Sourceimpl<'de> Deserialize<'de> for Capabilities
impl<'de> Deserialize<'de> for Capabilities
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl Deserialize for Capabilities
impl Deserialize for Capabilities
Sourcefn tls_deserialize<R: Read>(bytes: &mut R) -> Result<Self, Error>
fn tls_deserialize<R: Read>(bytes: &mut R) -> Result<Self, Error>
std only.bytes from the provided a std::io::Read
and returns the populated struct. Read moreSourceimpl DeserializeBytes for Capabilities
impl DeserializeBytes for Capabilities
Sourceimpl PartialEq for Capabilities
impl PartialEq for Capabilities
Sourceimpl Serialize for &Capabilities
impl Serialize for &Capabilities
Sourceimpl Serialize for Capabilities
impl Serialize for Capabilities
Sourceimpl Serialize for Capabilities
impl Serialize for Capabilities
Sourceimpl Size for &Capabilities
impl Size for &Capabilities
fn tls_serialized_len(&self) -> usize
Sourceimpl Size for Capabilities
impl Size for Capabilities
fn tls_serialized_len(&self) -> usize
impl Eq for Capabilities
impl StructuralPartialEq for Capabilities