pub struct ResumptionPskSecret { /* private fields */ }Available on 32-bit or 64-bit only.
A group secret that can be used among members to prove that a member was part of a group in a given epoch.
Implementations