pub struct GroupMigrationBundle { /* private fields */ }Available on crate feature
migration-import and (32-bit or 64-bit) only.Expand description
Bundle used to import a group exported from a previous OpenMLS version. See
GroupMigrationBundle::store.
A group and all of the group-associated data it owns, deserialized from a
previous OpenMLS version for migration. The mirror of the older version’s
MlsGroup::export_for_migration.
Implementations
Sourceimpl GroupMigrationBundle
impl GroupMigrationBundle
Sourcepub fn store<Storage: StorageProvider>(
&self,
storage: &Storage,
) -> Result<(), Storage::Error>
pub fn store<Storage: StorageProvider>( &self, storage: &Storage, ) -> Result<(), Storage::Error>
Store the migrated group and all of its group-associated data in the current storage format.
NOTE: This replaces any existing state for the group’s GroupId, under the same GroupId encoding.
Single-value tables are overwritten and the accumulate-style data (own leaf nodes, proposal queue) are cleared before writing.
Old-format entries under a different key encoding are not changed.