RestrictedProvider

Struct RestrictedProvider 

pub struct RestrictedProvider { /* private fields */ }
Available on (32-bit or 64-bit) and (crate features test-utils) only.
An OpenMlsProvider that only claims support for an explicit allowlist of ciphersuites while remaining fully functional otherwise.

Implementations

Source

impl RestrictedProvider

pub fn new(allowed: Vec<Ciphersuite>) -> Self

Creates a provider that claims support for exactly the given ciphersuites.

pub fn inner(&self) -> &OpenMlsRustCrypto

Returns an unrestricted provider sharing the same storage. Useful to set up state (e.g. key packages) that the restricted view then processes.