pub enum LeafNodeValidationError {
Lifetime(LifetimeError),
UnsupportedExtensions,
UnsupportedProposals,
UnsupportedCredentials,
CredentialNotInCapabilities,
ExtensionsNotInCapabilities,
CiphersuiteNotInCapabilities,
SignatureKeyAlreadyInUse,
EncryptionKeyAlreadyInUse,
InvalidLeafNodeSource,
LeafNodeCredentialNotSupportedByMember,
MemberCredentialNotSupportedByLeafNode,
}Expand description
Errors that can happen during leaf node validation.
Variants
Lifetime(LifetimeError)
See LifetimeError for more details.
UnsupportedExtensions
Extensions are not acceptable.
UnsupportedProposals
Proposals are not acceptable.
UnsupportedCredentials
Credentials are not acceptable.
CredentialNotInCapabilities
The leaf node’s credential type is not listed in the leaf node’s capabilities.“
ExtensionsNotInCapabilities
The leaf node’s extension types are not (all) listed in the leaf node’s capabilities.
CiphersuiteNotInCapabilities
The group’s ciphersuite is not listed in the leaf node’s capabilities.
SignatureKeyAlreadyInUse
The leaf node’s signature key is already used in the group.
EncryptionKeyAlreadyInUse
The leaf node’s encryption key is already used in the group.
InvalidLeafNodeSource
The leaf node source is invalid in the given context.
LeafNodeCredentialNotSupportedByMember
The leaf node credential is not supported by all members in the group.
MemberCredentialNotSupportedByLeafNode
The credential used by a member is not supported by this leaf node.