pub struct RatchetTree(/* private fields */);Available on 32-bit or 64-bit only.
An exported ratchet tree as used in, e.g., GroupInfo.
Implementations
Sourceimpl RatchetTree
impl RatchetTree
Sourcepub fn nodes(&self) -> impl Iterator<Item = &Node>
pub fn nodes(&self) -> impl Iterator<Item = &Node>
Returns an iterator over all nodes in the ratchet tree.
Sourcepub fn leaves(&self) -> impl Iterator<Item = &LeafNode>
pub fn leaves(&self) -> impl Iterator<Item = &LeafNode>
Returns an iterator over all leaf nodes in the ratchet tree.
Sourcepub fn parents(&self) -> impl Iterator<Item = &ParentNode>
pub fn parents(&self) -> impl Iterator<Item = &ParentNode>
Returns an iterator over all parent nodes in the ratchet tree.