TreeSync

Struct TreeSync 

pub struct TreeSync { /* private fields */ }
Available on 32-bit or 64-bit only.
The TreeSync struct holds an MlsBinaryTree instance, which contains the state that is synced across the group, as well as the LeafNodeIndex pointing to the leaf of this group member and the current hash of the tree.

It follows the same pattern of tree and diff as the underlying MlsBinaryTree, where the TreeSync instance is immutable safe for merging a TreeSyncDiff, which can be created, staged and merged (see TreeSyncDiff).

TreeSync instance guarantee a few invariants that are checked upon creating a new instance from an imported set of nodes, as well as when merging a diff.

Implementations

Source

impl TreeSync

pub fn full_leaves(&self) -> impl Iterator<Item = (LeafNodeIndex, &LeafNode)>

Returns an iterator over the (non-blank) LeafNodes in the tree.

pub fn full_parents( &self, ) -> impl Iterator<Item = (ParentNodeIndex, &ParentNode)>

Returns an iterator over the (non-blank) ParentNodes in the tree.

pub fn blank_parents<'a>(&'a self) -> impl Iterator<Item = ParentNodeIndex> + 'a

Returns an iterator over the ParentNodeIndexes of blank ParentNodes in the tree.

pub fn blank_leaves<'a>(&'a self) -> impl Iterator<Item = LeafNodeIndex> + 'a

Returns an iterator over the LeafNodeIndexes of blank LeafNodes in the tree.

pub fn export_ratchet_tree(&self) -> RatchetTree

Returns the nodes in the tree ordered according to the array-representation of the underlying binary tree.