pub struct StagedWelcome { /* private fields */ }Expand description
A StagedWelcome can be inspected and then turned into a MlsGroup.
This allows checking who authored the Welcome message.
Implementations
Sourceimpl StagedWelcome
impl StagedWelcome
Sourcepub fn new_from_welcome<Provider: OpenMlsProvider>(
provider: &Provider,
mls_group_config: &MlsGroupJoinConfig,
welcome: Welcome,
ratchet_tree: Option<RatchetTreeIn>,
) -> Result<Self, WelcomeError<Provider::StorageError>>
pub fn new_from_welcome<Provider: OpenMlsProvider>( provider: &Provider, mls_group_config: &MlsGroupJoinConfig, welcome: Welcome, ratchet_tree: Option<RatchetTreeIn>, ) -> Result<Self, WelcomeError<Provider::StorageError>>
Creates a new staged welcome from a Welcome message. Returns an error
(WelcomeError::NoMatchingKeyPackage) if no KeyPackage
can be found.
Note: calling this function will consume the key material for decrypting the Welcome
message, even if the caller does not turn the StagedWelcome into an MlsGroup.
Sourcepub fn build_from_welcome<'a, Provider: OpenMlsProvider>(
provider: &'a Provider,
mls_group_config: &MlsGroupJoinConfig,
welcome: Welcome,
) -> Result<JoinBuilder<'a, Provider>, WelcomeError<Provider::StorageError>>
pub fn build_from_welcome<'a, Provider: OpenMlsProvider>( provider: &'a Provider, mls_group_config: &MlsGroupJoinConfig, welcome: Welcome, ) -> Result<JoinBuilder<'a, Provider>, WelcomeError<Provider::StorageError>>
Similar to StagedWelcome::new_from_welcome but as a builder.
The builder allows to set the ratchet tree, skip leaf node lifetime
validation, and get the ProcessedWelcome for inspection before staging.
Sourcepub fn welcome_sender_index(&self) -> LeafNodeIndex
pub fn welcome_sender_index(&self) -> LeafNodeIndex
Returns the LeafNodeIndex of the group member that authored the Welcome message.
Sourcepub fn welcome_sender(&self) -> Result<&LeafNode, LibraryError>
pub fn welcome_sender(&self) -> Result<&LeafNode, LibraryError>
Sourcepub fn own_leaf_index(&self) -> LeafNodeIndex
pub fn own_leaf_index(&self) -> LeafNodeIndex
Returns the leaf index of the client in this welcome’s PublicGroup.
Sourcepub fn own_leaf_node(&self) -> Option<&LeafNode>
pub fn own_leaf_node(&self) -> Option<&LeafNode>
Returns the leaf node of the client in this welcome’s PublicGroup.
Sourcepub fn group_context(&self) -> &GroupContext
pub fn group_context(&self) -> &GroupContext
Get the GroupContext of this welcome’s PublicGroup.
Sourcepub fn members(&self) -> impl Iterator<Item = Member> + '_
pub fn members(&self) -> impl Iterator<Item = Member> + '_
Get an iterator over all Members of this welcome’s PublicGroup.
Sourcepub fn application_export_secret(&self) -> &ApplicationExportSecret
Available on crate feature extensions-draft only.
pub fn application_export_secret(&self) -> &ApplicationExportSecret
extensions-draft only.Get the ApplicationExportSecret of this welcome.
Sourcepub fn into_group<Provider: OpenMlsProvider>(
self,
provider: &Provider,
) -> Result<MlsGroup, WelcomeError<Provider::StorageError>>
pub fn into_group<Provider: OpenMlsProvider>( self, provider: &Provider, ) -> Result<MlsGroup, WelcomeError<Provider::StorageError>>
Consumes the StagedWelcome and returns the respective MlsGroup.
Sourcepub fn export_secret<CryptoProvider: OpenMlsCrypto>(
&self,
crypto: &CryptoProvider,
label: &str,
context: &[u8],
key_length: usize,
) -> Result<Vec<u8>, ExportSecretError>
pub fn export_secret<CryptoProvider: OpenMlsCrypto>( &self, crypto: &CryptoProvider, label: &str, context: &[u8], key_length: usize, ) -> Result<Vec<u8>, ExportSecretError>
Exports a secret from the epoch of the group that is joined
using this StagedWelcome.
Returns ExportSecretError::KeyLengthTooLong if the requested
key length is too long.