Struct VLByteVec
pub struct VLByteVec { /* private fields */ }Expand description
Variable-length encoded byte vector.
Functionally equivalent to VLBytes, but its serde representation uses
serde_bytes to serialize the contained byte vector as a byte blob via
#[serde(transparent)]. This produces a much more compact encoding for
serde formats that distinguish byte arrays from sequences of u8 (e.g.
CBOR, MessagePack, bincode).
While the serde format produced by VLByteVec is not compatible with
the format produced by VLBytes, VLByteVec’s custom Deserialize impl
is backwards-compatible: it accepts both its own native bytes encoding and
the legacy VLBytes encoding (a struct with a vec field containing a
sequence of u8). This lets callers transparently migrate persisted
VLBytes data to VLByteVec for self-describing formats such as CBOR,
JSON or MessagePack.
Implementations