pub struct RestrictedProvider { /* private fields */ }Available on (32-bit or 64-bit) and (crate features
test-utils) only.Expand description
An OpenMlsProvider that only claims support for an explicit allowlist
of ciphersuites while remaining fully functional otherwise.
Implementations
Sourceimpl RestrictedProvider
impl RestrictedProvider
Sourcepub fn new(allowed: Vec<Ciphersuite>) -> Self
pub fn new(allowed: Vec<Ciphersuite>) -> Self
Creates a provider that claims support for exactly the given ciphersuites.